import os
from pathlib import Path
import requests
from dotenv import load_dotenv

def fetch_input(filename):
    load_dotenv()

    stripped_filename = os.path.splitext(os.path.basename(filename))[0]
    year = os.path.basename(Path(filename).parent)
    day = stripped_filename.split("day")[1]
    directory = Path("inputs")
    input_path = directory / f"day{day}.txt"

    if input_path.exists():
        with open(input_path, "r") as file:
            return file.read()
        
    directory.mkdir(parents = True, exist_ok= True)
    url = f"https://adventofcode.com/{year}/day/{day}/input"
    cookie = os.getenv("AOC_COOKIE")
    headers = {"Cookie" : f"session={cookie}",
                                "User-Agent": "Python Script - Advent of Code Input Fetcher"}
    try:
        response = requests.get(url, headers = headers)
        response.raise_for_status()
        with open(input_path, "w") as file:
            file.write(response.text)
        return response.text
    except requests.exceptions.RequestException as e:
        print(f"Error: {e}")
        return None


from setuptools import setup, find_packages

setup(
    name="aoc_input_fetcher",
    version="0.1.1",
    description="A useful tool for getting the input automatically for Advent of Code, given you follow the file structure",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Mourud Ishmam Ahmed",
    author_email="ishmam1@gmail.com",
    url="https://github.com/mourud/aoc-input-fetcher",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[
        "requests",
        "python-dotenv",
    ],
    project_urls={
        "Bug Tracker": "https://github.com/mourud/aoc-input-fetcher/issues",
        "Documentation": "https://github.com/mourud/aoc-input-fetcher#readme",
    },
    keywords=["Advent of Code", "input fetcher", "automation"],
)
